@@ -57,8 +57,10 @@ pmml.rules <- function(model,
 
   # PMML -> Header
 
-  pmml <- append.XMLNode(pmml, .pmmlHeader(description, copyright,
-                                           model_version, app_name))
+  pmml <- append.XMLNode(pmml, .pmmlHeader(
+    description, copyright,
+    model_version, app_name
+  ))
 
   # PMML -> DataDictionary
 
