@@ -1,5 +1,3 @@
-library(amap)
-library(rattle)
 
 # necessary to unload rattle because it has a different "audit" dataset
 teardown({
@@ -8,11 +6,17 @@ teardown({
 })
 
 test_that("error when object is not hclust", {
+  skip_if_not_installed("amap")
+  library(amap)
   expect_error(pmml.hclust("foo"), "Not a legitimate hclust object")
 })
 
 
 test_that("appropriate number of clusters is created", {
+  skip_if_not_installed("amap")
+  skip_if_not_installed("rattle")
+  library(amap)
+  library(rattle)
   fit <- hclusterpar(iris[, -5])
   centerInfo <- rattle::centers.hclust(iris[, -5], fit, 3)
   p_fit <- pmml(fit, centers = centerInfo)
