@@ -1,11 +1,12 @@
-library(kernlab)
 data(iris)
 
-teardown({
-  detach("package:kernlab", unload = TRUE)
-})
+# teardown({
+#   detach("package:kernlab", unload = TRUE)
+# })
 
 test_that("pmml.ksvm error when a specified kernel is not supported", {
+  skip_if_not_installed("kernlab")
+  library(kernlab)
   expect_error(
     pmml(ksvm(Sepal.Length ~ ., data = iris, kernel = "laplacedot"), dataset = iris),
     "laplacedot kernel is not supported. Supported ksvm kernels: rbfdot, polydot, vanilladot, tanhdot."
