@@ -1,6 +1,3 @@
-library(nnet)
-data(iris)
-
 test_that("error when object is not multinom", {
   expect_error(pmml.multinom("foo"), "Not a legitimate multinom object")
 })
