@@ -1,25 +1,27 @@
-library(e1071)
 data("audit")
 
-set.seed(123)
-ft_1 <- runif(100) * 10
-ft_2 <- runif(100) * 7
-df_1 <- data.frame(ft_1, ft_2, stringsAsFactors = TRUE)
-anom_rows <- sample(1:100, 5)
-df_1[anom_rows, 1] <- sample(20:30, 5)
-df_1[anom_rows, 2] <- sample(20:30, 5)
-
-svm_model_1 <- svm(df_1,
-  y = NULL, type = "one-classification",
-  nu = 0.10, scale = TRUE, kernel = "radial"
-)
-
-
-teardown({
-  detach("package:e1071", unload = TRUE)
-})
+# teardown({
+#   detach("package:e1071", unload = TRUE)
+# })
 
 test_that("error when dataset is null for one-classification", {
+  skip_if_not_installed("e1071")
+  library(e1071)
+
+  set.seed(123)
+  ft_1 <- runif(100) * 10
+  ft_2 <- runif(100) * 7
+  df_1 <- data.frame(ft_1, ft_2, stringsAsFactors = TRUE)
+  anom_rows <- sample(1:100, 5)
+  df_1[anom_rows, 1] <- sample(20:30, 5)
+  df_1[anom_rows, 2] <- sample(20:30, 5)
+
+  svm_model_1 <- svm(df_1,
+    y = NULL, type = "one-classification",
+    nu = 0.10, scale = TRUE, kernel = "radial"
+  )
+
+
   expect_error(
     pmml(svm_model_1),
     "dataset must not be null for one-classification."
@@ -27,10 +29,29 @@ test_that("error when dataset is null for one-classification", {
 })
 
 test_that("pmml.svm no error when model is one-class svm", {
+  skip_if_not_installed("e1071")
+  library(e1071)
+
+  set.seed(123)
+  ft_1 <- runif(100) * 10
+  ft_2 <- runif(100) * 7
+  df_1 <- data.frame(ft_1, ft_2, stringsAsFactors = TRUE)
+  anom_rows <- sample(1:100, 5)
+  df_1[anom_rows, 1] <- sample(20:30, 5)
+  df_1[anom_rows, 2] <- sample(20:30, 5)
+
+  svm_model_1 <- svm(df_1,
+    y = NULL, type = "one-classification",
+    nu = 0.10, scale = TRUE, kernel = "radial"
+  )
+
+
   expect_silent(pmml(svm_model_1, dataset = df_1))
 })
 
 test_that("pmml.svm no error when model is one-class svm", {
+  skip_if_not_installed("e1071")
+  library(e1071)
   # set.seed(321)
   df_2 <- na.omit(audit)
 
@@ -45,13 +66,13 @@ test_that("pmml.svm no error when model is one-class svm", {
     nu = 0.10, scale = FALSE, kernel = "radial"
   )
 
-
   # expect_silent(pmml(svm_model_2,feature.info=sapply(df_2,class)))
   expect_silent(pmml(svm_model_2, dataset = df_2))
 })
 
-
 test_that("pmml.svm error when model is one-class svm and data has integer", {
+  skip_if_not_installed("e1071")
+  library(e1071)
   # set.seed(311)
   df_3 <- na.omit(audit)
   df_3 <- df_3[, c("Age", "Income", "Deductions", "Hours", "Adjustment", "Adjusted")]
@@ -70,8 +91,9 @@ test_that("pmml.svm error when model is one-class svm and data has integer", {
   )
 })
 
-
 test_that("pmml.svm error when model is one-class svm and formula interface is used", {
+  skip_if_not_installed("e1071")
+  library(e1071)
   data(iris)
   df_4 <- iris[, 1:3]
   fit <- svm(Petal.Length ~ ., data = df_4, type = "one-classification")
@@ -82,6 +104,8 @@ test_that("pmml.svm error when model is one-class svm and formula interface is u
 })
 
 test_that("Output node is formatted correctly for SV regression", {
+  skip_if_not_installed("e1071")
+  library(e1071)
   data(iris)
   fit <- svm(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width, data = iris)
   fit_pmml <- pmml(fit)
